mongol_code library

Classes

Menksoft
This class contains the coded values for the glyphs in the old Menksoft fonts. Unlike Mongolian Unicode, they encode text according to the written shape.
Mongol
Convenience class for the Mongolian Unicode values used in this package.
Suffix

Functions

convertMenksoftToUnicode(String inputString) String
convertUnicodeToMenksoft(String input) String
genderOf({required List<int> word, int? beforeIndex}) Gender