menu
mongol_code package
documentation
mongol_code.dart
mongol_code.dart
dark_mode
light_mode
mongol_code
library
Classes
Menksoft
This class contains the coded values for the glyphs in the old Menksoft fonts. Unlike Mongolian Unicode, they encode text according to the written shape.
Mongol
Convenience class for the Mongolian Unicode values used in this package.
Suffix
Enums
Gender
Location
Functions
convertMenksoftToUnicode
(
String
inputString
)
→
String
convertUnicodeToMenksoft
(
String
input
)
→
String
genderOf
(
{
required
List
<
int
>
word
,
int
?
beforeIndex
})
→
Gender
mongol_code package
documentation
mongol_code.dart
mongol_code
package
Libraries
mongol_code
mongol_code library